# sshdb

![Gif of the app](https://github.com/a-chacon/ssh-manager/blob/main/resources/sshdb.gif)

## Getting Started

Simple cli tool that save your ssh conection's data on a sqlite database. You can save the specific data for a host and select it for a create a conection through ssh.

### Prerequisites

- Python > 3
- Install requirements.txt

### Installing

Install it with pip:

```
python3 -m pip install sshdb
```

## Usage

See all options:
```
sshdb -h
```

## Built With

* [Python 3](http://www.dropwizard.io/1.0.2/docs/) - Language
* [Pip3](http://www.dropwizard.io/1.0.2/docs/) - Manager of package

## Authors

* **a-chacon** - *Initial work* - [a-chacon](https://github.com/a-chacon)

## License

This project is licensed under the GPLv3 - see the [LICENSE.md](LICENSE.md) file for details
